==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.server/src/com/openexchange/mail/config/MailAccountProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.config;

import static com.openexchange.java.Autoboxing.I;
import com.openexchange.mail.api.IMailProperties;
import com.openexchange.mailaccount.MailAccount;

/**
 * {@link MailAccountProperties} - Mail properties read from mail account with fallback to properties read from properties file.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class MailAccountProperties extends AbstractMailAccountProperties implements IMailProperties {

    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailAccountProperties.class);

    /** The mail server URL */
    protected final String url;

    /**
     * Initializes a new {@link MailAccountProperties}.
     *
     * @param mailAccount The mail account
     * @param userId The user identifier
     * @param contextId The context identifier
     * @throws IllegalArgumentException If provided mail account is <code>null</code>
     */
    public MailAccountProperties(MailAccount mailAccount, int userId, int contextId) {
        super(mailAccount, userId, contextId);
        if (null == mailAccount) {
            throw new IllegalArgumentException("mail account is null.");
        }
        String tmp;
        try {
            tmp = mailAccount.generateMailServerURL();
        } catch (final Exception e) {
            LOG.warn("Failed to generate mail server URL from account {} of user {} in contrext {}.", I(mailAccount.getId()), I(userId), I(contextId), e);
            tmp = null;
        }
        url = tmp;
    }

    @Override
    public int getMailFetchLimit() {
        return lookUpIntProperty("com.openexchange.mail.mailFetchLimit", MailProperties.getInstance().getMailFetchLimit());
    }

    @Override
    public boolean isAllowNestedDefaultFolderOnAltNamespace() {
        return lookUpBoolProperty("com.openexchange.mail.allowNestedDefaultFolderOnAltNamespace", MailProperties.getInstance().isAllowNestedDefaultFolderOnAltNamespace());
    }

    @Override
    public boolean isIgnoreSubscription() {
        return lookUpBoolProperty("com.openexchange.mail.ignoreSubscription", MailProperties.getInstance().isIgnoreSubscription());
    }

    @Override
    public boolean isSupportSubscription() {
        return lookUpBoolProperty("com.openexchange.mail.supportSubscription", MailProperties.getInstance().isSupportSubscription());
    }

    @Override
    public boolean isUserFlagsEnabled() {
        return lookUpBoolProperty("com.openexchange.mail.userFlagsEnabled", MailProperties.getInstance().isUserFlagsEnabled());
    }

    @Override
    public void waitForLoading() throws InterruptedException {
        MailProperties.getInstance().waitForLoading();
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/mail/config/MailAccountProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.config;

import com.openexchange.mail.api.IMailProperties;
import com.openexchange.mailaccount.MailAccount;

/**
 * {@link MailAccountProperties} - Mail properties read from mail account with fallback to properties read from properties file.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class MailAccountProperties extends AbstractMailAccountProperties implements IMailProperties {

    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailAccountProperties.class);

    /**
     * Initializes a new {@link MailAccountProperties}.
     *
     * @param mailAccount The mail account
     * @param userId The user identifier
     * @param contextId The context identifier
     */
    public MailAccountProperties(MailAccount mailAccount, int userId, int contextId) {
        super(mailAccount, userId, contextId);
    }

    @Override
    public int getMailFetchLimit() {
        return lookUpIntProperty("com.openexchange.mail.mailFetchLimit", MailProperties.getInstance().getMailFetchLimit());
    }

    @Override
    public boolean hideInlineImages() {
        return lookUpBoolProperty("com.openexchange.mail.hideInlineImages", MailProperties.getInstance().hideInlineImages());
    }

    @Override
    public boolean isAllowNestedDefaultFolderOnAltNamespace() {
        return lookUpBoolProperty("com.openexchange.mail.allowNestedDefaultFolderOnAltNamespace", MailProperties.getInstance().isAllowNestedDefaultFolderOnAltNamespace());
    }

    @Override
    public boolean isIgnoreSubscription() {
        return lookUpBoolProperty("com.openexchange.mail.ignoreSubscription", MailProperties.getInstance().isIgnoreSubscription());
    }

    @Override
    public boolean isSupportSubscription() {
        return lookUpBoolProperty("com.openexchange.mail.supportSubscription", MailProperties.getInstance().isSupportSubscription());
    }

    @Override
    public boolean isUserFlagsEnabled() {
        return lookUpBoolProperty("com.openexchange.mail.userFlagsEnabled", MailProperties.getInstance().isUserFlagsEnabled());
    }

    @Override
    public void waitForLoading() throws InterruptedException {
        MailProperties.getInstance().waitForLoading();
    }

}
